@@ -20,8 +20,8 @@ for (dir in c('up', 'right', 'down', 'le')) {
 
 ## ----Do plotting---------------------------------------------------------
 par(mfrow=c(1, 2), mar=rep(0.3, 4))
-TernaryPlot(alab="Redder\u2192", blab="Greener \u2192", clab="Bluer \u2192",
-            point='right', lab.cex=0.8, grid.minor.lines = 0,
+TernaryPlot(alab="Redder \u2192", blab="\u2190 Greener", clab="Bluer \u2192",
+            point='right', lab.cex=0.8, grid.minor.lines=0,
             grid.lty='solid', col=rgb(0.9, 0.9, 0.9), grid.col='white', 
             axis.col=rgb(0.6, 0.6, 0.6), ticks.col=rgb(0.6, 0.6, 0.6),
             padding=0.08)
@@ -34,23 +34,27 @@ data_points <- list(
   I = c(92, 12, 243),
   V = c(225, 24, 208)
 )
-AddToTernary(points, data_points, bg=vapply(data_points, function (x) rgb(x[1], x[2], x[3], 128, maxColorValue=255), character(1)), pch=21, cex=2.8)
+AddToTernary(points, data_points, pch=21, cex=2.8, 
+             bg=vapply(data_points, 
+                       function (x) rgb(x[1], x[2], x[3], 128, maxColorValue=255),
+                       character(1))
+             )
 AddToTernary(text, data_points, names(data_points), cex=0.8, font=2)
 legend('bottomright', 
-       pch=21, pt.cex=1.8,
-       pt.bg=c(rgb(255, 0, 0,   128, NULL, 255), 
-             rgb(240, 180,  52, 128, NULL, 255),
-             rgb(210, 222, 102, 128, NULL, 255),
-             rgb(111, 222,  16, 128, NULL, 255)),
-       legend=c('Red', 'Orange', 'Yellow', 'Green'), 
-       cex=0.8, bty='n')
+       legend=c('Red', 'Orange', 'Yellow', 'Green'),
+       cex=0.8, bty='n', pch=21, pt.cex=1.8,
+       pt.bg=c(rgb(255,   0,   0, 128, NULL, 255), 
+               rgb(240, 180,  52, 128, NULL, 255),
+               rgb(210, 222, 102, 128, NULL, 255),
+               rgb(111, 222,  16, 128, NULL, 255)),
+       )
 
 ###
 # Next plot:
 ###
 TernaryPlot('Steam', 'Ice', 'Water', 
             grid.lines=5, grid.lty='dotted',
-            grid.minor.lines = 1, grid.minor.lty='dotted',
+            grid.minor.lines=1, grid.minor.lty='dotted',
             point='West')
 HorizontalGrid()
 middle_triangle <- matrix(c(
@@ -62,6 +66,7 @@ TernaryPolygon(middle_triangle, col='#aaddfa', border='grey')
 TernaryLines(list(c(0, 100, 0), middle_triangle[1, ]), col='grey')
 TernaryLines(list(c(0, 0, 100), middle_triangle[2, ]), col='grey')
 TernaryLines(list(c(100, 0, 0), middle_triangle[3, ]), col='grey')
+TernaryArrows(c(20, 20, 60), c(30, 30, 40), length=0.2, col='darkblue')
 
 ## ----Cartesian-----------------------------------------------------------
 TernaryPlot(point='right')
